EasyExtend.util.hexobject.Bits

Package EasyExtend :: Package util :: Module hexobject :: Class Bits |
[hide private]
[frames] | no frames]

# Class Bits

    object --+
             |
          list --+
                 |
                Bits

Instance Methods | [hide private]
new list |
__init__(self, l) x.__init__(...) initializes x; see x.__class__.__doc__ for signature |
__repr__(self) repr(x) |
Inherited from `list`: `__add__`, `__contains__`, `__delitem__`, `__delslice__`, `__eq__`, `__ge__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__gt__`, `__hash__`, `__iadd__`, `__imul__`, `__iter__`, `__le__`, `__len__`, `__lt__`, `__mul__`, `__ne__`, `__new__`, `__reversed__`, `__rmul__`, `__setitem__`, `__setslice__`, `append`, `count`, `extend`, `index`, `insert`, `pop`, `remove`, `reverse`, `sort` Inherited from `object`: `__delattr__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__str__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, l) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Returns: new list Overrides: object.__init__ (inherited documentation)

### __repr__(self) (Representation operator) |
repr(x) Overrides: object.__repr__ (inherited documentation)